# NiWrap Helper

Package of utility functions to help make working with NiWrap easier (namely for use
with scripts).

> [!IMPORTANT]
> Version `0.2.x` is incompatible with `0.1.x` due to breaking changes in [`bids2table`]. Any previously created indices will **need** to be recreated.

<!-- Links -->
[`bids2table`]: https://github.com/childmindresearch/bids2table
